import json

def load_from_file(filename, encode_format='utf-8'):
    '''ファイルからJSONとしてロード'''
    
    return json.load(open(filename, 'r', encoding=encode_format))

def save_to_file(json_obj, filename, indent=2, encode_format='utf-8'):
    '''JSONをファイルへ保存'''

    json.dump(json_obj, open(filename, 'w', encoding=encode_format), indent=indent, ensure_ascii=False)

def print_json(json_obj, indent=2):
    '''JSONを整形して表示'''
    
    print(json.dumps(json_obj, indent=indent, ensure_ascii=False))

def json_from_str(text):
    '''str型からJSONへ変換'''

    return json.loads(text)

def json_to_str(json_obj):
    '''JSONをstr型へ変換'''

    return json.dumps(json_obj, ensure_ascii=False).replace(' ', '')


import datetime

def get_timestamp():
    '''現在時刻のタイムスタンプを取得'''
    JST = datetime.timezone(datetime.timedelta(hours=+9), 'JST')
    now = datetime.datetime.now(JST)

    return now.strftime('%Y%m%d%H%M%S%f')

def conv_time_from_timestamp(timestamp):
    '''タイムスタンプをdatetimeに変換'''
    time = datetime.datetime.strptime(timestamp+'+0900', '%Y%m%d%H%M%S%f%z')

    return time


from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='reelib',
    packages=find_packages(),

    version='1.1.0',

    license='MIT',

    install_requires=[],

    author='reeve0930',
    author_email='reeve0930@gmail.com',

    url='https://github.com/reeve0930/reelib',

    description='頻繁に利用する処理を集めたライブラリ',
    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords='reelib', 

    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.6'
    ],
)